// Georgui Rekouts, Nov 1994
// dlgtest.cpp - Implementation of the test dialog class

#include "DlgTest.h"

// ---------------------------------- DlgTestWindow constructor
TDlgTestWindow::TDlgTestWindow() :
  TWindow(0, 0, 0)
{
  Outliner = new TTSCTreeList(this, IDC_LISTBOX1, 10, 10, 300, 200);
  Outliner->Attr.Style |= WS_BORDER;
  Font = NULL;
}

// ---------------------------------- DlgTestWindow destructor
TDlgTestWindow::~TDlgTestWindow()
{
  delete Outliner;
  delete Font;
}

// ---------------------------------- SetupWindow
void TDlgTestWindow::SetupWindow()
{
  TWindow::SetupWindow();
  view = Outliner->AddView(new TStringView);
  view->SetOpenBitmap (new TBitmap(*GetApplication(), "OPEN"));
  view->SetCloseBitmap(new TBitmap(*GetApplication(), "CLOSE"));
  view->SetNodeBitmap (new TBitmap(*GetApplication(), "NODE"));

  TNode *nodeRoot = Outliner->GetNodeRoot();
  TNode *node = Outliner->AddNode(nodeRoot, new TStringNode("Parent A"), view);
					 Outliner->AddNode(node,       new TStringNode("child i"), view);
  TNode *sub1 = Outliner->AddNode(node,       new TStringNode("SubParent B"), view);
					 Outliner->AddNode(sub1,         new TStringNode("child ii"), view);
  TNode *sub2 = Outliner->AddNode(sub1,         new TStringNode("SubParent C"), view);
					 Outliner->AddNode(sub2,           new TStringNode("child iii"), view);
					 Outliner->AddNode(sub2,           new TStringNode("child iv"), view);
					 Outliner->AddNode(node,       new TStringNode("child v"), view);
  node        = Outliner->AddNode(nodeRoot, new TStringNode("Parent D"), view);
  sub1        = Outliner->AddNode(node,       new TStringNode("SubParent E"), view);
					 Outliner->AddNode(sub1,         new TStringNode("child vi"), view);
					 Outliner->AddNode(sub1,         new TStringNode("child vii"), view);
					 Outliner->AddNode(node,       new TStringNode("child viii"), view);
  Outliner->Update();
}

DEFINE_RESPONSE_TABLE1(TDlgTestWindow, TWindow)
  EV_COMMAND(CM_MODAL, CmModal),
  EV_COMMAND(CM_CHANGEFONT, CmChangeFont),
  EV_COMMAND(CM_CHANGEINDENTUNITS, CmChangeIndentUnits),
  EV_COMMAND(CM_ADDITEM, CmAddItem ),
  EV_COMMAND(CM_REMOVEITEM, CmRemoveItem ),
END_RESPONSE_TABLE;

void TDlgTestWindow::CmModal()
{
  TMyModal modal(this, "ModalDialog");
  modal.Execute();
}

void TDlgTestWindow::CmAddItem()
{
  int ind = Outliner->GetSelIndex();
  TNode *nodeRoot = Outliner->GetSelectedNode();
  Outliner->AddNode(nodeRoot, new TStringNode("Test - New Node"), view);
  Outliner->Update();
  Outliner->SetSelIndex( ind );
}

void TDlgTestWindow::CmRemoveItem()
{
  int ind = Outliner->GetSelIndex();
  delete Outliner->RemoveNode( Outliner->GetSelIndex() );
  Outliner->Update();
  Outliner->SetSelIndex( ind );
}


void TDlgTestWindow::CmChangeFont()
{
  if (Font)
	 FontData.Flags |= CF_INITTOLOGFONTSTRUCT;
  else
  {
	 FontData.DC         = 0;
	 FontData.Flags      = CF_EFFECTS | CF_FORCEFONTEXIST | CF_SCREENFONTS;
	 FontData.Color      = RGB(0, 0, 0);
	 FontData.Style      = 0;
	 FontData.FontType   = SCREEN_FONTTYPE;
	 FontData.SizeMin    = 0;
	 FontData.SizeMax    = 0;
  }
  TChooseFontDialog dialog(this, FontData);
  if (dialog.Execute() == IDOK)
  {
    TFont *tempFont = new TFont(&FontData.LogFont);
    Outliner->SendMessage(WM_SETFONT, (WPARAM)(HFONT)*tempFont,
      MAKELPARAM(TRUE, 0));
    if (Font != NULL)
      delete Font;
    Font = tempFont;
    Outliner->Update();
  }
}

void TDlgTestWindow::CmChangeIndentUnits()
{
  char buffer[10];
  wsprintf(buffer, "%d", Outliner->GetIndentUnits());
  TInputDialog input(this, "Change indent units",
    "Indent units", buffer, 10);
  if (input.Execute() == IDOK)
  {
    int units = atoi(buffer);
    if (units > 10)
    {
      Outliner->SetIndentUnits(units);
      Outliner->Update();
    }
  }
}

