// Georgui Rekouts, Nov, 1994
// strnode.cpp - Implementation of TStringNode and TStringView

#include "treelist.h"

//---------- TTSCTreeList will call a view to display the node's information
void TStringView::Paint( DRAWITEMSTRUCT &drawInfo, TNode *node,
  TFont *font, int indentUnits)
{
  TDC   dc( drawInfo.hDC );
  TRect eraseRect( drawInfo.rcItem );

  //............ erase background
  HBRUSH hBkgndBrush = CreateSolidBrush( GetSysColor(COLOR_WINDOW) );
  dc.FillRect( eraseRect, hBkgndBrush );
  DeleteBrush( hBkgndBrush );

  //....... call TNodeView to display the bitmaps
  TNodeView::Paint( drawInfo, node, font, indentUnits);

  //............ extracting draw info
  TRect rect( drawInfo.rcItem );

  //....... draw the node's information (text string)
  TStringNode *stringNode = TYPESAFE_DOWNCAST(node, TStringNode);
  if (font)
  {
	 dc.SelectObject(*font);
  }


  TColor colorBkOld;
  TColor colorTextOld;

  if (drawInfo.itemState & ODS_SELECTED)
  {
	  hBkgndBrush = CreateSolidBrush( GetSysColor(COLOR_HIGHLIGHT) );
	  dc.FillRect( rect, hBkgndBrush );
	  DeleteBrush( hBkgndBrush );

	  TColor colorBk( GetSysColor(COLOR_HIGHLIGHT) );
	  TColor colorText( GetSysColor(COLOR_HIGHLIGHTTEXT) );
	  colorBkOld   = dc.SetBkColor( colorBk );
	  colorTextOld = dc.SetTextColor( colorText );
  }

  dc.DrawText(stringNode->GetString().c_str(), -1, rect,
	 DT_SINGLELINE | DT_VCENTER);

  if (drawInfo.itemState & ODS_FOCUS)
  {
	 dc.DrawFocusRect(rect);

  }

  if (drawInfo.itemState & ODS_SELECTED)
  {
	 dc.SetBkColor( colorBkOld );
	 dc.SetTextColor( colorTextOld );
  }

  if ( font )
  {
	 dc.RestoreFont();
  }
}

//---------------------------------------------------- Get Size
void TStringView::GetSize(TNode *node, TFont *font, TSize &size)
{
  TNodeView::GetSize(node, font, size);
}

//-------------------------------------------------- TStringNode
TStringNode::TStringNode(char *str) :
  ItemString(str)
{
}

TStringNode::TStringNode(string str):
  ItemString(str)
{
}

TStringNode::~TStringNode()
{
}

//--------------------------------- TListImp's required operators
TStringNode::TStringNode(const TStringNode &copyString)
{
  SetString(copyString.GetString());
}

TStringNode& TStringNode::operator = (const TStringNode &copyString)
{
  // copy base class first
  *(TNode *)this = *(TNode *)&copyString;
  SetString(copyString.GetString());
  return *this;
}

int TStringNode::operator == (const TStringNode &compString) const
{
  return ItemString == compString.GetString();
}


